@@ -9,6 +9,7 @@
 
 #include "Formatter.h"
 
+#include <KFormat>
 #include <KLocalizedString>
 
 #include <QFontMetrics>
@@ -16,14 +17,9 @@
 #include <QTime>
 
 #include <cmath>
-
-#ifdef Q_OS_OSX
-#include <mach/clock.h>
-#include <mach/mach.h>
-#else
 #include <ctime>
-#endif
 
+#include <time.h>
 #include <unistd.h>
 
 #include "formatter_debug.h"
@@ -279,12 +275,30 @@ static QString formatNumber(const QVariant &value, Unit unit, MetricPrefix prefi
 
 static QString formatTime(const QVariant &value)
 {
-    const qlonglong seconds = value.toLongLong();
+    return KFormat().formatDuration(value.toLongLong() * 1000);
+}
 
-    const QString minutesString = QString::number(seconds / 60);
-    const QString secondsScring = QStringLiteral("%1").arg(seconds % 60, 2, 10, QLatin1Char('0'));
+static QString formatTicks(const QVariant &value)
+{
+    auto seconds = value.toLongLong() / sysconf(_SC_CLK_TCK);
+    return KFormat().formatDuration(seconds * 1000);
+}
 
-    return minutesString + QLatin1Char(':') + secondsScring;
+static QString formatBootTimestamp(const QVariant &value)
+{
+    timespec tp;
+#ifdef Q_OS_LINUX
+    clock_gettime(CLOCK_BOOTTIME, &tp);
+#else
+    clock_gettime(CLOCK_MONOTONIC, &tp);
+#endif
+
+    const QDateTime systemBootTime = QDateTime::currentDateTime().addSecs(-tp.tv_sec);
+
+    const qreal secondsSinceSystemBoot = value.toReal() / sysconf(_SC_CLK_TCK);
+    const QDateTime absoluteTimeSinceBoot = systemBootTime.addSecs(secondsSinceSystemBoot);
+
+    return KFormat().formatRelativeDateTime(absoluteTimeSinceBoot, QLocale::ShortFormat);
 }
 
 qreal Formatter::scaleDownFactor(const QVariant &value, Unit unit, MetricPrefix targetPrefix)
@@ -342,12 +356,13 @@ QString Formatter::formatValue(const QVariant &value, Unit unit, MetricPrefix ta
         return formatNumber(value, unit, targetPrefix, options);
 
     case UnitBootTimestamp:
-        qCWarning(FORMATTER) << "UnitBootTimestamp is deprecated and is not formatted anymore";
-        return value.toString();
+        return formatBootTimestamp(value);
     case UnitTime:
         return formatTime(value);
     case UnitNone:
         return formatNumber(value, unit, MetricPrefix::MetricPrefixUnity, options);
+    case UnitTicks:
+        return formatTicks(value);
 
     default:
         return value.toString();
